@@ -99,6 +99,8 @@ function Startup()
   gDialog.targetRadiogroup        = document.getElementById("targetRadiogroup");
   gDialog.userDefinedTarget       = document.getElementById("userDefinedTarget");
 
+  gDialog.technoratiTag           = document.getElementById("technoratiTag");
+
   // See if we have a single selected image
   imageElement = gActiveEditor.getSelectedElement("img");
 
@@ -283,17 +285,17 @@ function InitDialog()
   SetRelativeCheckbox(gDialog.makeRelativeLink);
 
   var relAttr = globalElement.getAttribute("rel");
-  var xfnArray = null;
+  var relValuesArray = null;
   if (relAttr)
-    xfnArray = relAttr.split(" ");
+    relValuesArray = relAttr.split(" ");
 
-  if (xfnArray)
+  if (relValuesArray)
   {
-    var i, l = xfnArray.length;
+    var i, l = relValuesArray.length;
     var e;
     for (i=0; i<l; i++)
     {
-      var val = xfnArray[i];
+      var val = relValuesArray[i];
       switch (val) {
         case "me":
           gDialog.meCheckbox.checked = true;
@@ -327,6 +329,9 @@ function InitDialog()
           e = document.getElementById(val + "Radio");
           gDialog.familyRadiogroup.selectedItem = e;
           break;
+        case "tag":
+          gDialog.technoratiTag.checked = true;
+          break;
       }
     }
   }
@@ -336,17 +341,23 @@ function InitDialog()
   if (targetValue)
   {
     gDialog.userDefinedTargetCheckbox.checked = true;
+    gDialog.userDefinedTarget.setAttribute("disabled", true);
     switch (targetValue) {
       case "_top":
+        gDialog.targetRadiogroup.selectedIndex = 0;
+        break;
       case "_blank":
+        gDialog.targetRadiogroup.selectedIndex = 1;
+        break;
       case "_parent":
+        gDialog.targetRadiogroup.selectedIndex = 2;
+        break;
       case "_self":
-        e = document.getElementById(targetValue.substr(1) + "Radio");
-        gDialog.targetRadiogroup.selectedItem = e;
+        gDialog.targetRadiogroup.selectedIndex = 3;
         break;
       default:
-        e = document.getElementById("userdefRadio");
-        gDialog.targetRadiogroup.selectedItem = e;
+        gDialog.targetRadiogroup.selectedIndex = 4;
+        gDialog.userDefinedTarget.removeAttribute("disabled");
         gDialog.userDefinedTarget.value = targetValue;
         break;
     }
@@ -471,7 +482,7 @@ function ValidateData()
 
 function doHelpButton()
 {
-  openHelp("link_properties");
+  openHelp('comp-doc-link','chrome://help/locale/nvu.rdf');
   return true;
 }
 
@@ -552,12 +563,12 @@ function ToggleRelValue(val)
     return;
   }
 
-  var xfnArray = relValue.split(" ");
-  var i, l = xfnArray.length;
+  var relValuesArray = relValue.split(" ");
+  var i, l = relValuesArray.length;
   var found = -1;
   for (i=0; i<l; i++)
   {
-    if (xfnArray[i] == val)
+    if (relValuesArray[i] == val)
     {
       found = i;
       break;
@@ -580,16 +591,19 @@ function ToggleRelValue(val)
     return;
   }
 
-  xfnArray[found] = "";
-  l = xfnArray.length;
+  relValuesArray[found] = "";
+  l = relValuesArray.length;
   relValue = "";
   for (i=0; i<l; i++)
   {
     if (i)
       relValue += " ";
-    relValue += xfnArray[i];
+    relValue += relValuesArray[i];
   }
-  globalElement.setAttribute("rel", relValue);
+  if (relValue)
+    globalElement.setAttribute("rel", relValue);
+  else
+    globalElement.removeAttribute("rel");
 }
 
 
@@ -614,19 +628,19 @@ function RemoveRelValues(aGroup)
   }
 
   var relValue = globalElement.getAttribute("rel");
-  var xfnArray = relValue.split(" ");
-  var i, j, l = xfnArray.length, values = groupValues.length;
+  var relValuesArray = relValue.split(" ");
+  var i, j, l = relValuesArray.length, values = groupValues.length;
   for (i=0; i<l; i++)
     for (j=0; j<values; j++)
-      if (xfnArray[i] == groupValues[j])
-        xfnArray[i] = "";
+      if (relValuesArray[i] == groupValues[j])
+        relValuesArray[i] = "";
 
   relValue = "";
   for (i=0; i<l; i++)
   {
     if (i)
       relValue += " ";
-    relValue += xfnArray[i];
+    relValue += relValuesArray[i];
   }
   globalElement.setAttribute("rel", relValue);
 }
@@ -634,7 +648,12 @@ function RemoveRelValues(aGroup)
 function ToggleTargetValue(value)
 {
   if (value == "user-defined")
+  {
     value = gDialog.userDefinedTarget.value;
+    gDialog.userDefinedTarget.removeAttribute("disabled");
+  }
+  else
+    gDialog.userDefinedTarget.setAttribute("disabled", true);
   globalElement.setAttribute("target", value);
 }
 
