@@ -535,12 +535,27 @@ nsXMLContentSerializer::SerializeAttr(const nsAString& aPrefix,
       else
         sValue.ReplaceSubstring(NS_LITERAL_STRING("\"").get(), NS_LITERAL_STRING("&quot;").get());
       mInAttribute = PR_TRUE;
-      AppendToString(sValue, aStr, PR_FALSE);
+      if (mFlags & nsIDocumentEncoder::OutputForColoredSourceView)
+      {
+        nsAutoString dummyStr;
+        AppendToString(sValue, dummyStr, PR_TRUE);
+        AppendToString(dummyStr, aStr, PR_TRUE);
+      }
+      else
+        AppendToString(sValue, aStr, PR_FALSE);
       mInAttribute = PR_FALSE;
     }
     else {
       mInAttribute = PR_TRUE;
-      AppendToString(aValue, aStr, PR_FALSE);
+      if (mFlags & nsIDocumentEncoder::OutputForColoredSourceView)
+      {
+        nsAutoString dummyStr;
+        mFlags -= nsIDocumentEncoder::OutputForColoredSourceView;
+        AppendToString(aValue, aStr, PR_TRUE);
+        mFlags += nsIDocumentEncoder::OutputForColoredSourceView;
+      }
+      else
+        AppendToString(aValue, aStr, PR_FALSE);
       mInAttribute = PR_FALSE;
     }
     if (mFlags & nsIDocumentEncoder::OutputForColoredSourceView)
